$.jqplot.BarRenderer

A plugin renderer for jqPlot to draw a bar plot. Draws series as a line.

Summary

$.jqplot.BarRenderer | A plugin renderer for jqPlot to draw a bar plot.
Properties |
barPadding | Number of pixels between adjacent bars at the same axis value.
barMargin | Number of pixels between groups of bars at adjacent axis values.
barDirection | ‘vertical’ = up and down bars, ‘horizontal’ = side to side bars
barWidth | Width of the bar in pixels (auto by devaul).
shadowOffset | offset of the shadow from the slice and offset of each succesive stroke of the shadow from the last.
shadowDepth | number of strokes to apply to the shadow, each stroke offset shadowOffset from the last.
shadowAlpha | transparency of the shadow (0 = transparent, 1 = opaque)
waterfall | true to enable waterfall plot.
groups | group bars into this many groups
varyBarColor | true to color each bar of a series separately rather than have every bar of a given series the same color.
highlightMouseOver | True to highlight slice when moused over.
highlightMouseDown | True to highlight when a mouse button is pressed over a slice.
highlightColors | an array of colors to use when highlighting a bar.
transposedData | NOT IMPLEMENTED YET.

### Properties

### barPadding

> this.barPadding = 8

Number of pixels between adjacent bars at the same axis value.

### barMargin

> this.barMargin = 10

Number of pixels between groups of bars at adjacent axis values.

### barDirection

> this.barDirection = 'vertical'

’vertical’ = up and down bars, ‘horizontal’ = side to side bars

### barWidth

> this.barWidth = null

Width of the bar in pixels (auto by devaul). null = calculated automatically.

### shadowOffset

> this.shadowOffset = 2

offset of the shadow from the slice and offset of each succesive stroke of the shadow from the last.

### shadowDepth

> this.shadowDepth = 5

number of strokes to apply to the shadow, each stroke offset shadowOffset from the last.

### shadowAlpha

> this.shadowAlpha = 0.08

transparency of the shadow (0 = transparent, 1 = opaque)

### waterfall

> this.waterfall = false

true to enable waterfall plot.

### groups

> this.groups = 1

group bars into this many groups

### varyBarColor

> this.varyBarColor = false

true to color each bar of a series separately rather than have every bar of a given series the same color. If used for non-stacked multiple series bar plots, user should specify a separate ‘seriesColors’ array for each series. Otherwise, each series will set their bars to the same color array. This option has no Effect for stacked bar charts and is disabled.

### highlightMouseOver

> this.highlightMouseOver = true

True to highlight slice when moused over. This must be false to enable highlightMouseDown to highlight when clicking on a slice.

### highlightMouseDown

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice. This will be disabled if highlightMouseOver is true.

### highlightColors

> this.highlightColors = []

an array of colors to use when highlighting a bar.

### transposedData

> this.transposedData = true

NOT IMPLEMENTED YET. True if this is a horizontal bar plot and x and y values are “transposed”. Tranposed, or “swapped”, data is required prior to rev. 894 builds of jqPlot with horizontal bars. Allows backward compatability of bar renderer horizontal bars with old style data sets.

> this.barPadding = 8

Number of pixels between adjacent bars at the same axis value.

> this.barMargin = 10

Number of pixels between groups of bars at adjacent axis values.

> this.barDirection = 'vertical'

‘vertical’ = up and down bars, ‘horizontal’ = side to side bars

> this.barWidth = null

Width of the bar in pixels (auto by devaul).

> this.shadowOffset = 2

offset of the shadow from the slice and offset of each succesive stroke of the shadow from the last.

> this.shadowDepth = 5

number of strokes to apply to the shadow, each stroke offset shadowOffset from the last.

> this.shadowAlpha = 0.08

transparency of the shadow (0 = transparent, 1 = opaque)

> this.waterfall = false

true to enable waterfall plot.

> this.groups = 1

group bars into this many groups

> this.varyBarColor = false

true to color each bar of a series separately rather than have every bar of a given series the same color.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightColors = []

an array of colors to use when highlighting a bar.

> this.transposedData = true

NOT IMPLEMENTED YET.
Close